This is unreleased documentation for Yew Next version.
For up-to-date documentation, see the latest version on docs.rs.

HasAllProps

Trait HasAllProps 

pub trait HasAllProps<P, How> { }
A marker trait to ensure that the builder has received all required props. For each struct deriving Properties, an impl is generated, requiring HasProp<p> for all properties marked as required as a bound on the impl.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> HasAllProps<(), T> for T