pub trait IntoPropValue<T> {
// Required method
fn into_prop_value(self) -> T;
}Expand description
A trait similar to Into<T> which allows conversion to a value of a Properties struct.
Required Methods
Sourcefn into_prop_value(self) -> T
fn into_prop_value(self) -> T
Convert self to a value of a Properties struct.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".